@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
  *
@@ -313,38 +313,35 @@ void sflphone_fill_account_list (void)
     sflphone_fill_codec_list ();
 }
 
-gboolean sflphone_init()
+gboolean sflphone_init (GError **error)
 {
-
-    if (!dbus_connect ()) {
-
-        main_window_error_message (_ ("Unable to connect to the SFLphone server.\nMake sure the daemon is running."));
+    if (!dbus_connect (error))
         return FALSE;
-    } else {
-        dbus_register (getpid(), "Gtk+ Client");
 
-        // Init icons factory
-        init_icon_factory ();
+    if (!dbus_register (getpid (), "Gtk+ Client", error))
+        return FALSE;
 
-        current_calls = calltab_init (FALSE, CURRENT_CALLS);
-        contacts = calltab_init (TRUE, CONTACTS);
-        history = calltab_init (TRUE, HISTORY);
+    // Init icons factory
+    init_icon_factory ();
 
-        account_list_init ();
-        codec_capabilities_load ();
-        conferencelist_init ();
+    current_calls = calltab_init (FALSE, CURRENT_CALLS);
+    contacts = calltab_init (TRUE, CONTACTS);
+    history = calltab_init (TRUE, HISTORY);
 
-        // Fetch the configured accounts
-        sflphone_fill_account_list ();
+    account_list_init ();
+    codec_capabilities_load ();
+    conferencelist_init ();
 
-        // Fetch the ip2ip profile
-        sflphone_fill_ip2ip_profile();
+    // Fetch the configured accounts
+    sflphone_fill_account_list ();
 
-        // Fetch the conference list
-        // sflphone_fill_conference_list();
+    // Fetch the ip2ip profile
+    sflphone_fill_ip2ip_profile();
 
-        return TRUE;
-    }
+    // Fetch the conference list
+    // sflphone_fill_conference_list();
+
+    return TRUE;
 }
 
 void sflphone_fill_ip2ip_profile (void)
@@ -1189,10 +1186,6 @@ void sflphone_fill_codec_list_per_account (account_t **account)
     }
 
     (*account)->codecs = codeclist;
-
-    // call dbus function with array of strings
-    codec_list_update_to_daemon (*account);
-
 }
 
 void sflphone_fill_call_list (void)
