@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Julien Bonjean <julien.bonjean@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -96,7 +96,6 @@ addressbook_is_active()
 static void
 addressbook_config_books()
 {
-
     gchar **config_book_uid;
     book_data_t *book_data;
     gchar **list;
@@ -104,27 +103,23 @@ addressbook_config_books()
     // Retrieve list of books
     list = (gchar **) dbus_get_addressbook_list();
 
-    if (list) {
+    if (list == NULL)
+        return;
 
-        for (config_book_uid = list; *config_book_uid; config_book_uid++) {
+    for (config_book_uid = list; *config_book_uid; config_book_uid++) {
 
-            // Get corresponding book data
-            book_data = books_get_book_data_by_uid (*config_book_uid);
-
-            // If book_data exists
-            if (!book_data) {
-                ERROR ("Addressbook: Error: Could not open book (%s:%d)", __FILE__, __LINE__);
-                continue;
-            }
+        // Get corresponding book data
+        book_data = books_get_book_data_by_uid (*config_book_uid);
 
+        // If book_data exists
+        if (book_data == NULL) {
+            ERROR ("Addressbook: Error: Could not open book (%s:%d)", __FILE__, __LINE__);
+        } else {
             book_data->active = TRUE;
         }
-
-        g_strfreev (list);
     }
 
-    // Update buttons
-    // update_actions ();
+    g_strfreev (list);
 }
 
 /**
@@ -137,8 +132,9 @@ addressbook_get_books_data()
 
     fill_books_data();
     addressbook_config_books();
+    determine_default_addressbook();
 
-    return books_data;
+    return get_books_data();
 }
 
 /**
@@ -152,6 +148,7 @@ addressbook_init()
 
     fill_books_data();
     addressbook_config_books();
+    determine_default_addressbook();
 
     // Call books initialization
     init ();
