@@ -42,6 +42,7 @@
 #include <pango/pango.h>
 #include "eds.h"
 #include <addressbook-config.h>
+#include <libedataserverui/e-passwords.h>
 
 /**
  * Structure used to store search callback and data
@@ -54,16 +55,19 @@ typedef struct _Search_Handler_And_Data {
     EBookQuery *equery;
 } Search_Handler_And_Data;
 
+static void
+authenticate_source (EBook *);
+
+/**
+ * The global addressbook list
+ */
+GSList *books_data = NULL;
+
 /**
  * Size of image that will be displayed in contact list
  */
 static int pixbuf_size = 32;
 
-/**
- * Remaining books to open (asynchronous)
- */
-int remaining_books_to_open;
-
 /**
  * Current selected addressbook's uri and uid, initialized with default
  */
@@ -73,6 +77,12 @@ static gchar *current_name = "Default";
 
 static EBookQueryTest current_test = E_BOOK_QUERY_BEGINS_WITH;
 
+
+/**
+ * Prototypes
+ */
+void empty_books_data();
+
 /**
  * Freeing a hit instance
  */
@@ -86,12 +96,26 @@ free_hit (Hit *h)
     g_free (h);
 }
 
+/**
+ * Free a book data
+ */
+void
+free_book_data (book_data_t *data)
+{
+    g_free (data->name);
+    g_free (data->uid);
+    g_free (data->uri);
+}
+
 /**
  * Public way to know if we can perform a search
  */
 gboolean
 books_ready()
 {
+    if (books_data == NULL)
+        return 0;
+
     return (g_slist_length (books_data) > 0);
 }
 
@@ -104,7 +128,7 @@ books_active()
     GSList *book_list_iterator;
     book_data_t *book_data;
 
-    if (!books_data) {
+    if (books_data == NULL) {
         DEBUG ("Addressbook: No books data (%s:%d)", __FILE__, __LINE__);
         return FALSE;
     }
@@ -130,7 +154,7 @@ books_get_book_data_by_uid (gchar *uid)
     GSList *book_list_iterator;
     book_data_t *book_data;
 
-    if (!books_data) {
+    if (books_data == NULL) {
         DEBUG ("Addressbook: No books data (%s:%d)", __FILE__, __LINE__);
         return NULL;
     }
@@ -246,7 +270,7 @@ view_finish_callback (EBookView *book_view, Search_Handler_And_Data *had)
 
     g_free (had);
 
-    DEBUG ("Addressbook: View finish");
+    DEBUG ("Addressbook: View finish, all book have been processed");
 
     if (book_view != NULL)
         g_object_unref (book_view);
@@ -280,8 +304,6 @@ eds_query_result_cb (EBook *book, EBookStatus status, GList *contacts, gpointer
 
     if (status == E_BOOK_ERROR_OK) {
 
-        gchar *number;
-
         // make sure we have a new list of hits
         had->hits = NULL;
 
@@ -295,37 +317,17 @@ eds_query_result_cb (EBook *book, EBookStatus status, GList *contacts, gpointer
 
                 // Get the photo contact
                 hit->photo = pixbuf_from_contact (E_CONTACT (l->data));
-
-                // Get business phone information
-                fetch_information_from_contact (E_CONTACT (l->data), E_CONTACT_PHONE_BUSINESS, &number);
-                hit->phone_business = g_strdup (number);
-
-                // Get home phone information
-                fetch_information_from_contact (E_CONTACT (l->data), E_CONTACT_PHONE_HOME, &number);
-                hit->phone_home = g_strdup (number);
-
-                // Get mobile phone information
-                fetch_information_from_contact (E_CONTACT (l->data), E_CONTACT_PHONE_MOBILE, &number);
-                hit->phone_mobile = g_strdup (number);
-
+                fetch_information_from_contact (E_CONTACT (l->data), E_CONTACT_PHONE_BUSINESS, &hit->phone_business);
+                fetch_information_from_contact (E_CONTACT (l->data), E_CONTACT_PHONE_HOME, &hit->phone_home);
+                fetch_information_from_contact (E_CONTACT (l->data), E_CONTACT_PHONE_MOBILE, &hit->phone_mobile);
                 hit->name = g_strdup ( (char *) e_contact_get_const (E_CONTACT (l->data), E_CONTACT_NAME_OR_ORG));
 
                 if (!hit->name)
                     hit->name = "";
 
-                /*
-                        DEBUG ("Addressbook: Contact Found");
-                        DEBUG ("Addressbook:     Full Name %s", hit->name);
-                        DEBUG ("Addressbook:     Phone Home %s", hit->phone_home);
-                        DEBUG ("Addressbook:     Phone Business %s", hit->phone_business);
-                        DEBUG ("Addressbook:     Phone Mobile %s", hit->phone_mobile);
-                */
-
                 if (hit)
                     had->hits = g_list_append (had->hits, hit);
 
-
-                // DEBUG ("Addressbook: max_result_remaining %d", had->max_results_remaining);
                 had->max_results_remaining--;
 
                 if (had->max_results_remaining <= 0)
@@ -353,10 +355,21 @@ eds_async_open_callback (EBook *book, EBookStatus status, gpointer closure)
 {
     DEBUG ("Addressbook: Open book callback");
 
+    ESource *source;
+    const gchar *uri;
+
     Search_Handler_And_Data *had = (Search_Handler_And_Data *) closure;
 
     if (status == E_BOOK_ERROR_OK) {
 
+        if (! (source = e_book_get_source (book)))
+            DEBUG ("Addressbook: Error while getting source");
+
+        if (! (uri = e_book_get_uri (book)))
+            DEBUG ("Addressbook: Error while getting URI");
+
+        authenticate_source (book);
+
         if (!e_book_is_opened (book)) {
             // We must open the addressbook
             e_book_open (book, FALSE, NULL);
@@ -451,67 +464,83 @@ eds_async_open_callback (EBook *book, EBookStatus status, gpointer closure)
 void
 init ()
 {
-    GError *err = NULL;
-    gchar *absuri, *reluri;
+    GSList *book_list_iterator;
+    book_data_t *book_data;
 
-    EBook *default_addressbook = e_book_new_default_addressbook (&err);
+    DEBUG ("Addressbook: Init default addressbook");
 
-    if (err)
-        ERROR ("Addressbook: Error: Could not create new book from source: %s", err->message);
-
-    ESource *default_source = e_book_get_source (default_addressbook);
-
-    // DEBUG ("Addressbook: Default source relative uri %s", e_source_peek_relative_uri (default_source));
-    // DEBUG ("Addressbook: Default source absolute uri %s", e_source_peek_absolute_uri (default_source));
-
-    if (current_uri) {
-        g_free (current_uri);
-        current_uri = NULL;
+    if (books_data == NULL) {
+        DEBUG ("Addressbook: No books data (%s:%d)", __FILE__, __LINE__);
+        return;
     }
 
-    if (current_uid) {
-        g_free (current_uid);
-        current_uid = NULL;
+    // Iterate throw the list
+    for (book_list_iterator = books_data; book_list_iterator != NULL;
+            book_list_iterator = book_list_iterator->next) {
+        book_data = (book_data_t *) book_list_iterator->data;
+
+        if (book_data->isdefault) {
+            current_uri = book_data->uri;
+            current_uid = book_data->uid;
+            current_name = book_data->name;
+        }
     }
-
-    if (strcmp (current_name, "Default") != 0) {
-        g_free (current_name);
-        current_name = NULL;
-    }
-
-    // TODO: This should work but return a NULL pointer ...
-    // if (! (group = e_source_peek_group (default_source)));
-
-    // ERROR ("Addressbook: Error: No group found for default addressbook");
-
-    absuri = g_strdup (e_source_peek_absolute_uri (default_source));
-    // absuri = g_strdup (e_source_group_peek_base_uri (group));
-    reluri = g_strdup (e_source_peek_relative_uri (default_source));
-
-    if (!absuri) {
-        absuri = g_malloc (1);
-        *absuri = 0;
-    }
-
-    if (!reluri) {
-        reluri = g_malloc (1);
-        *reluri = 0;
-    }
-
-    // Do not overwrite current_name for default
-    // current_name = g_strdup (e_source_peek_name (default_source));
-
-    current_uid = g_strdup (e_source_peek_uid (default_source));
-
-    if (strcmp (absuri+strlen (absuri)-1, "/") == 0)
-        current_uri = g_strjoin ("", absuri, reluri, NULL);
-    else
-        current_uri = g_strjoin ("/", absuri, reluri, NULL);
-
-    g_free (absuri);
-    g_free (reluri);
 }
 
+/**
+ * Authenticate this addressbook
+ */
+static void
+authenticate_source (EBook *book)
+{
+    const gchar *auth_domain;
+    const gchar *password = NULL;
+    const gchar *component_name;
+    const gchar *user;
+    const gchar *auth;
+    GError *err = NULL;
+    const gchar *uri;
+    ESource *source;
+    gboolean ret;
+
+    if (! (source = e_book_get_source (book)))
+        DEBUG ("Addressbook: Error while getting source");
+
+    if (! (uri = e_book_get_uri (book)))
+        DEBUG ("Addressbook: Error while getting URI");
+
+    auth_domain = e_source_get_property (source, "auth-domain");
+
+    auth = e_source_get_property (source, "auth");
+
+    if (auth && !strcmp ("ldap/simple-binddn", auth)) {
+        user = e_source_get_property (source, "binddn");
+    } else if (auth && !strcmp ("plain/password", auth)) {
+        user = e_source_get_property (source, "user");
+
+        if (!user) {
+            user = e_source_get_property (source, "username");
+        }
+    } else {
+        user = e_source_get_property (source, "email_addr");
+    }
+
+    if (!user)
+        user = "";
+
+    if (auth) {
+        component_name = auth_domain ? auth_domain : "Addressbook";
+
+        password = e_passwords_get_password (component_name, uri);
+
+        ret = e_book_authenticate_user (book, user, password, auth, &err);
+
+        if (ret)
+            DEBUG ("Addressbook: authentication successfull");
+        else
+            DEBUG ("Addressbook: authentication error");
+    }
+}
 
 /**
  * Fill book data
@@ -521,8 +550,9 @@ fill_books_data ()
 {
     GSList *list, *l;
     ESourceList *source_list = NULL;
-    remaining_books_to_open = 0;
-    books_data = NULL;
+    gboolean default_found;
+
+    DEBUG ("Addressbook: Fill books data");
 
     source_list = e_source_list_new_for_gconf_default ("/apps/evolution/addressbook/sources");
 
@@ -538,14 +568,19 @@ fill_books_data ()
         return;
     }
 
+    if (books_data != NULL) {
+        empty_books_data();
+        books_data = NULL;
+    }
+
+    // in case default property is not set for any addressbook
+    default_found = FALSE;
 
     for (l = list; l != NULL; l = l->next) {
 
         ESourceGroup *group = l->data;
         GSList *sources = NULL, *m;
-        gchar *absuri;
-
-        absuri = g_strdup (e_source_group_peek_base_uri (group));
+        gchar *absuri = g_strdup (e_source_group_peek_base_uri (group));
 
         sources = e_source_group_peek_sources (group);
 
@@ -561,19 +596,25 @@ fill_books_data ()
             const gchar *property_name = "default";
             const gchar *prop = e_source_get_property (source, property_name);
 
-            if (prop)
-                if (strcmp (prop, "true") == 0)
+            if (prop) {
+                if (strcmp (prop, "true") == 0) {
                     book_data->isdefault = TRUE;
-                else
+                    default_found = TRUE;
+                } else {
                     book_data->isdefault = FALSE;
-            else
+                }
+            } else {
                 book_data->isdefault = FALSE;
+            }
 
             if (strcmp (absuri+strlen (absuri)-1, "/") == 0)
                 book_data->uri = g_strjoin ("", absuri, e_source_peek_relative_uri (source), NULL);
             else
                 book_data->uri = g_strjoin ("/", absuri, e_source_peek_relative_uri (source), NULL);
 
+
+            // authenticate_source (book_data, source);
+
             books_data = g_slist_prepend (books_data, book_data);
 
         }
@@ -584,6 +625,59 @@ fill_books_data ()
     g_object_unref (source_list);
 }
 
+void
+determine_default_addressbook()
+{
+    GSList *list_element = books_data;
+    gboolean default_found = FALSE;
+
+    while (list_element && !default_found) {
+        book_data_t *book_data = list_element->data;
+
+        if (book_data->isdefault)
+            default_found = TRUE;
+
+        list_element = g_slist_next (list_element);
+    }
+
+    // reset loop
+    list_element = books_data;
+
+    while (list_element && !default_found) {
+        book_data_t *book_data = list_element->data;
+
+        if (book_data->active) {
+            book_data->isdefault = TRUE;
+            DEBUG ("Addressbook: No default addressbook found, using %s addressbook as default", book_data->name);
+            default_found = TRUE;
+        }
+
+        list_element = g_slist_next (list_element);
+    }
+}
+
+void
+empty_books_data()
+{
+    GSList *book_list_iterator;
+    book_data_t *book_data;
+
+    if (books_data == NULL) {
+        DEBUG ("Addressbook: No books data (%s:%d)", __FILE__, __LINE__);
+        return;
+    }
+
+    // Iterate throw the list
+    for (book_list_iterator = books_data; book_list_iterator != NULL;
+            book_list_iterator = book_list_iterator->next) {
+        book_data = (book_data_t *) book_list_iterator->data;
+
+        free_book_data (book_data);
+    }
+
+
+}
+
 void
 search_async_by_contacts (const char *query, int max_results, SearchAsyncHandler handler, gpointer user_data)
 {
@@ -662,7 +756,7 @@ set_current_addressbook (const gchar *name)
 
     if (!books_data) {
         DEBUG ("Addressbook: No books data (%s:%d)", __FILE__, __LINE__);
-        return NULL;
+        return;
     }
 
     // Iterate throw the list
@@ -697,3 +791,9 @@ get_current_addressbook_test (void)
 {
     return current_test;
 }
+
+GSList *
+get_books_data()
+{
+    return books_data;
+}
