@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
@@ -41,6 +41,7 @@
 #include "uimanager.h"
 #include "actions.h"
 #include "../imwindow.h"
+#include "searchbar.h"
 
 GtkWidget *sw;
 GtkCellRenderer *rend;
@@ -1400,6 +1401,8 @@ void calltree_display (calltab_t *tab)
         }
 
         gtk_toggle_tool_button_set_active ( (GtkToggleToolButton*) contactButton, TRUE);
+
+        set_forcus_on_addressbook_searchbar();
     }
 
     else
