@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
@@ -38,6 +38,7 @@ Account::Account (const AccountID& accountID, std::string type) :
     , _link (NULL)
     , _enabled (true)
     , _type (type)
+    , _registrationState (Unregistered)
     , _codecOrder ()
     , _codecStr ("0/")
     , _ringtonePath ("/usr/share/sflphone/ringtones/konga.ul")
@@ -45,7 +46,6 @@ Account::Account (const AccountID& accountID, std::string type) :
     , _displayName ("")
     , _useragent ("SFLphone")
 {
-    setRegistrationState (Unregistered);
 }
 
 Account::~Account()
