@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
@@ -107,6 +107,16 @@ class AudioRtpFactory
          */
         void stop();
 
+        /**
+         * Return the RTP payload currently used for this session
+         */
+        int getSessionMedia();
+
+        /**
+         * Dynamically update session media
+         */
+        void updateSessionMedia (AudioCodec *);
+
         /**
          * Update current RTP destination address with one stored in call
          * @param None
