@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -60,18 +61,27 @@ class AudioZrtpSession : protected ost::Thread, public AudioRtpRecordHandler, pu
 
         ~AudioZrtpSession();
 
+        virtual void final();
+
         // Thread associated method
         virtual void run ();
 
         virtual bool onRTPPacketRecv (ost::IncomingRTPPkt&);
 
-        int startRtpThread (AudioCodec*);
+        int startRtpThread (AudioCodec *);
+
+        void stopRtpThread (void);
 
         /**
          * Used mostly when receiving a reinvite
          */
         void updateDestinationIpAddress (void);
 
+        /**
+         * Update audio codec dynamically
+         */
+        void updateSessionMedia (AudioCodec *);
+
         /**
          * Send DTMF over RTP (RFC2833). The timestamp and sequence number must be
          * incremented as if it was microphone audio. This function change the payload type of the rtp session,
@@ -99,9 +109,6 @@ class AudioZrtpSession : protected ost::Thread, public AudioRtpRecordHandler, pu
          */
         void setDestinationIpAddress (void);
 
-
-        void notifyIncomingCall();
-
         /**
          * Send encoded data to peer
          */
@@ -114,8 +121,6 @@ class AudioZrtpSession : protected ost::Thread, public AudioRtpRecordHandler, pu
 
         std::string _zidFilename;
 
-        ost::Time * _time;
-
         // This semaphore is not used
         // but is needed in order to avoid
         // ambiguous compiling problem.
@@ -157,12 +162,9 @@ class AudioZrtpSession : protected ost::Thread, public AudioRtpRecordHandler, pu
          */
         short _timestampCount;
 
-        /**
-         * Time counter used to trigger incoming call notification
-         */
-        int _countNotificationTime;
-
         SIPCall * _ca;
+
+        bool _isStarted;
 };
 
 }
