@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -126,13 +126,21 @@ class Celt : public AudioCodec
 
         virtual int codecDecode (short *dst, unsigned char *src, unsigned int size) {
             int err = 0;
+#ifdef USE_091
+            err = celt_decode (_dec, src, size, (celt_int16*) dst, size);
+#else
             err = celt_decode (_dec, src, size, (celt_int16*) dst);
+#endif
             return _frameSize * sizeof (celt_int16);
         }
 
         virtual int codecEncode (unsigned char *dst, short *src, unsigned int size) {
             int len = 0;
+#ifdef USE_091
+            len = celt_encode (_enc, (celt_int16*) src, size, dst, 40);
+#else
             len = celt_encode (_enc, (celt_int16*) src, (celt_int16 *) src, dst, 40);
+#endif
             // returns the number of bytes writen
             return len;
         }
