@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author : Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *
@@ -50,7 +50,7 @@ MainBuffer::~MainBuffer()
 void MainBuffer::setInternalSamplingRate (int sr)
 {
 
-    if (sr != _internalSamplingRate) {
+    if (sr > _internalSamplingRate) {
 
         _debug ("MainBuffer: Internal sampling rate changed %d", sr);
 
