@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author : Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *
@@ -38,7 +38,7 @@
 
 int Conference::count = 0;
 
-Conference::Conference()
+Conference::Conference() : _id (""), _confState (Active_Atached), _nbParticipant (0)
 {
     _nbParticipant = 0;
 
