@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *
@@ -64,16 +64,16 @@ IAXVoIPLink::IAXVoIPLink (const AccountID& accountID) : VoIPLink (accountID)
     , converter (NULL)
     , converterSamplingRate (NULL)
     , urlhook (NULL)
-    , countTime (0)
 {
     _evThread = new EventThread (this);
 
     // to get random number for RANDOM_PORT
     srand (time (NULL));
 
-    converter = new SamplerateConverter();
+    converter = new SamplerateConverter (44100, 20);
 
-    int nbSamplesMax = (int) (converter->getFrequence() * converter->getFramesize() / 1000);
+    // int nbSamplesMax = (int) (converter->getFrequence() * converter->getFramesize() / 1000);
+    int nbSamplesMax = (44100 * 20) / 1000;
 
     micData = new SFLDataFormat[nbSamplesMax];
     micDataConverted = new SFLDataFormat[nbSamplesMax];
@@ -245,7 +245,7 @@ IAXVoIPLink::getEvent()
 {
     IAXCall* call = NULL;
 
-    Manager::instance().getAudioLayerMutex()->enter();
+    // Manager::instance().getAudioLayerMutex()->enter();
 
     // lock iax_ stuff..
     _mutexIAX.enterMutex();
@@ -282,7 +282,7 @@ IAXVoIPLink::getEvent()
 
     sendAudioFromMic();
 
-    Manager::instance().getAudioLayerMutex()->leave();
+    // Manager::instance().getAudioLayerMutex()->leave();
 
     // Do the doodle-moodle to send audio from the microphone to the IAX channel.
     // sendAudioFromMic();
@@ -292,22 +292,6 @@ IAXVoIPLink::getEvent()
         sendRegister ("");
     }
 
-    // Notify (with a beep) an incoming call when there is already a call
-    countTime += 3;
-
-    if ( (Manager::instance().incomingCallWaiting() > 0) && Manager::instance().hasCurrentCall()) {
-
-        int countTime_modulo = countTime % 4000;
-        // _debug("countTime: %i", countTime);
-        // _debug("countTime_modulo: %i", countTime_modulo);
-
-        if ( (countTime_modulo - countTime) < 0) {
-            Manager::instance().notificationIncomingCall();
-        }
-
-        countTime = countTime_modulo;
-    }
-
     // thread wait 3 millisecond
     _evThread->sleep (3);
 
