@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
@@ -49,9 +49,9 @@ static const pj_str_t STR_CRYPTO = { (char*) "crypto", 6 };
 
 
 Sdp::Sdp (pj_pool_t *pool)
-    : _local_media_cap()
+    : _negociator (NULL)
+    , _local_media_cap()
     , _session_media (0)
-    , _negociator (NULL)
     , _ip_addr ("")
     , _local_offer (NULL)
     , _negociated_offer (NULL)
@@ -63,8 +63,6 @@ Sdp::Sdp (pj_pool_t *pool)
 
 Sdp::~Sdp()
 {
-    // clean_session_media();
-    // clean_local_media_capabilities();
 }
 
 void Sdp::set_media_descriptor_line (sdpMedia *media, pjmedia_sdp_media** p_med)
@@ -222,6 +220,7 @@ int Sdp::create_initial_offer (CodecOrder selectedCodecs)
 
 int Sdp::receiving_initial_offer (pjmedia_sdp_session* remote, CodecOrder selectedCodecs)
 {
+    _debug ("SDP: Receiving initial offer");
 
     // Create the SDP negociator instance by calling
     // pjmedia_sdp_neg_create_w_remote_offer with the remote offer, and by providing the local offer ( optional )
@@ -263,6 +262,8 @@ pj_status_t Sdp::check_sdp_answer (pjsip_inv_session *inv, pjsip_rx_data *rdata)
     pjsip_msg * message = NULL;
     pjmedia_sdp_session * remote_sdp = NULL;
 
+    _debug ("Sdp: Check SDP answer");
+
     if (pjmedia_sdp_neg_get_state (inv->neg) == PJMEDIA_SDP_NEG_STATE_LOCAL_OFFER) {
 
         message = rdata->msg_info.msg;
@@ -489,6 +490,7 @@ void Sdp::clean_session_media()
         sdpMedia *media;
 
         while (iter != _session_media.end()) {
+            _debug ("delete media");
             media = *iter;
             delete media;
             iter++;
@@ -524,13 +526,14 @@ void Sdp::set_negotiated_sdp (const pjmedia_sdp_session *sdp)
     int nb_media, nb_codecs;
     int i,j, port;
     pjmedia_sdp_media *current;
-    sdpMedia *media;
+    sdpMedia *media = NULL;
     std::string type, dir;
     CodecsMap codecs_list;
-    CodecsMap::iterator iter;
     pjmedia_sdp_attr *attribute = NULL;
     pjmedia_sdp_rtpmap *rtpmap;
 
+    _debug ("SDP: Set negotiated SDP");
+
     _negociated_offer = (pjmedia_sdp_session*) sdp;
 
     codecs_list = Manager::instance().getCodecDescriptorMap().getCodecsMap();
@@ -556,7 +559,7 @@ void Sdp::set_negotiated_sdp (const pjmedia_sdp_session *sdp)
 
             pjmedia_sdp_attr_to_rtpmap (_pool, attribute, &rtpmap);
 
-            iter = codecs_list.find ( (AudioCodecType) pj_strtoul (&rtpmap->pt));
+            CodecsMap::iterator iter = codecs_list.find ( (AudioCodecType) pj_strtoul (&rtpmap->pt));
 
             if (iter==codecs_list.end())
                 return;
@@ -576,7 +579,7 @@ AudioCodec* Sdp::get_session_media (void)
     AudioCodec *codec = NULL;
     std::vector<sdpMedia*> media_list;
 
-    _debug ("SDP: Executing sdp line %d - get_session_media()", __LINE__);
+    _debug ("SDP: Get session media");
 
     media_list = get_session_media_list ();
     nb_media = media_list.size();
@@ -597,6 +600,8 @@ pj_status_t Sdp::start_negociation()
 {
     pj_status_t status;
 
+    _debug ("Sdp: Start negotiation");
+
     if (_negociator) {
         status = pjmedia_sdp_neg_negotiate (_pool, _negociator, 0);
     } else {
